@@ -1,49 +1,59 @@
 from __future__ import annotations
-from typing import Sequence, Union, Optional, Callable, Any
+from typing import Sequence, Optional, Any
 
 import numpy as np
-import pandas as pd
 import tensorflow as tf
 
+from sknlp.vocab import Vocab
 from .nlp_dataset import NLPDataset
+from .bert_mixin import BertDatasetMixin
 from .utils import serialize_example
 
 
 class ClassificationDataset(NLPDataset):
     def __init__(
         self,
-        tokenizer: Callable[[str], list[int]],
+        vocab: Vocab,
         labels: Sequence[str],
+        segmenter: Optional[str] = None,
         X: Optional[Sequence[Any]] = None,
         y: Optional[Sequence[Any]] = None,
         csv_file: Optional[str] = None,
         in_memory: bool = True,
-        no_label: bool = False,
-        is_multilabel: bool = True,
+        has_label: bool = True,
+        is_multilabel: bool = False,
+        is_pair_text: bool = False,
         max_length: Optional[int] = None,
-        text_dtype: tf.DType = tf.int32,
+        text_dtype: tf.DType = tf.int64,
         label_dtype: tf.DType = tf.float32,
+        **kwargs,
     ):
         self.labels = list(labels)
+        self.is_pair_text = is_pair_text
         self.is_multilabel = is_multilabel
+        column_dtypes = ["str", "str"]
+        if self.is_pair_text:
+            column_dtypes.append("str")
         self.label2idx = dict(zip(labels, range(len(labels))))
         super().__init__(
-            tokenizer,
+            vocab,
+            segmenter=segmenter,
             X=X,
             y=y,
             csv_file=csv_file,
             in_memory=in_memory,
-            no_label=no_label,
+            has_label=has_label,
             max_length=max_length,
             na_value="NULL",
-            column_dtypes=["str", "str"],
+            column_dtypes=column_dtypes,
             text_dtype=text_dtype,
             label_dtype=label_dtype,
+            **kwargs,
         )
 
     @property
-    def y(self) -> Union[list[str], list[list[str]]]:
-        if self.no_label:
+    def y(self) -> list[str] | list[list[str]]:
+        if not self.has_label:
             return []
         return [
             data[-1].decode("UTF-8").split("|")
@@ -54,26 +64,27 @@ class ClassificationDataset(NLPDataset):
 
     @property
     def batch_padding_shapes(self) -> list[tuple]:
-        return ((None,), (None,))[: -1 if self.no_label else None]
+        shapes = [(None,), (None,)]
+        return shapes[: None if self.has_label else -1]
 
-    def _normalize_y(self, y: Sequence[Any]) -> Sequence[Any]:
+    def _format_y(self, y: Sequence[Any]) -> list[Sequence[Any]]:
         if isinstance(y[0], (list, tuple)):
-            return ["|".join(map(str, yi)) for yi in y]
-        return y
+            y = ["|".join(map(str, yi)) for yi in y]
+        return [y]
 
-    def _label_binarizer(self, labels: list[str]) -> np.ndarray:
+    def py_label_binarizer(self, labels: list[str]) -> np.ndarray:
         label2idx = self.label2idx
         res = np.zeros(len(label2idx), dtype=np.float32)
         res[[label2idx[label] for label in labels if label in label2idx]] = 1
         return res
 
-    def _label_transform(self, label: tf.Tensor) -> np.ndarray:
-        _label = super()._label_transform(label)
+    def py_label_transform(self, label: tf.Tensor) -> np.ndarray:
+        _label = super().py_label_transform(label)
         if self.is_multilabel:
             labels = _label.split("|")
         else:
             labels = [_label]
-        return self._label_binarizer(labels)
+        return self.py_label_binarizer(labels)
 
     def to_tfrecord(self, filename: str) -> None:
         def func(text: np.ndarray, label: np.ndarray):
@@ -108,4 +119,8 @@ class ClassificationDataset(NLPDataset):
                 tf.io.parse_tensor(parsed_record["feature1"], tf.float32),
             )
 
-        return tf.data.TFRecordDataset(filename).map(func)
\ No newline at end of file
+        return tf.data.TFRecordDataset(filename).map(func)
+
+
+class BertClassificationDataset(BertDatasetMixin, ClassificationDataset):
+    pass
\ No newline at end of file
