@@ -4,6 +4,7 @@ from typing import Optional
 import tensorflow as tf
 from tensorflow.keras.metrics import Accuracy, BinaryAccuracy
 
+from sknlp.utils.tensor import pad2shape
 from .utils import logits2pred
 
 
@@ -25,6 +26,7 @@ class AccuracyWithLogits(Accuracy):
         sample_weight: Optional[tf.Tensor] = None,
     ) -> None:
         y_pred = logits2pred(y_logits, self.activation)
+        y_pred = pad2shape(y_pred, tf.shape(y_true), value=0)
         super().update_state(y_true, y_pred, sample_weight=sample_weight)
 
     def get_config(self) -> dict[str, str]:
@@ -33,12 +35,22 @@ class AccuracyWithLogits(Accuracy):
 
 @tf.keras.utils.register_keras_serializable(package="sknlp")
 class BinaryAccuracyWithLogits(BinaryAccuracy):
+    def __init__(
+        self,
+        name: str = "accuracy",
+        dtype: Optional[tf.DType] = None,
+        threshold: float = 0.5,
+        activation: str = "linear",
+    ) -> None:
+        super().__init__(name=name, dtype=dtype, threshold=threshold)
+        self.activation = activation
+
     def update_state(
         self,
         y_true: tf.Tensor,
-        y_pred: tf.Tensor,
+        y_logits: tf.Tensor,
         sample_weight: Optional[tf.Tensor] = None,
     ) -> None:
-        super().update_state(
-            y_true, tf.math.sigmoid(y_pred), sample_weight=sample_weight
-        )
+        y_pred = logits2pred(y_logits, self.activation)
+        y_pred = pad2shape(y_pred, tf.shape(y_true), value=0)
+        super().update_state(y_true, y_pred, sample_weight=sample_weight)
